IEncrypter class abstract
Contract for encryption operations.
Defines the interface for encrypting and decrypting data using a key-based encryption scheme.
Implement this interface to provide a custom encryption strategy to RelaxStorage.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decrypt(
String encryptedText, String key) → String -
Decrypts an
encryptedTextpayload using the providedkey. -
deriveKey(
String key, {String? customSalt}) → Key -
Derives an AES encryption key from the given
keystring. -
encrypt<
T> (T data, String key) → String -
Encrypts
datausing the providedkey. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited